@@ -35,6 +35,14 @@ APIGW = 'api.blueline.mg'
 PROGRAMS = redis.Redis(host=ADDRESS)
 MEDIA = redis.Redis(host=ADDRESS, db=1)
 INFOS = redis.Redis(host=ADDRESS, db=15)
+MEDIA_SYNOPSIS_DB = '{eng}://{user}:{password}@{host}:{port}/{name}'.format(
+    eng=CONFIG['MEDIA_SYNOPSIS_DB']['engine'],
+    user=CONFIG['MEDIA_SYNOPSIS_DB']['user'],
+    password=CONFIG['MEDIA_SYNOPSIS_DB']['password'],
+    host=CONFIG['MEDIA_SYNOPSIS_DB']['host'],
+    port=CONFIG['MEDIA_SYNOPSIS_DB']['port'],
+    name=CONFIG['MEDIA_SYNOPSIS_DB']['name']
+    )
 TODAY = datetime.now().strftime('%d%m%Y')
 SERVICES = [
     int(i.split('SERVICE:')[1])
