@@ -2,6 +2,7 @@
 
 from .consts import CONFIG
 from .consts import MEDIA
+from .consts import MEDIA_SYNOPSIS_DB
 from .consts import PROGRAMS
 from . import program
 from . import cluster
@@ -15,6 +16,8 @@ import subprocess
 import time
 import threading
 
+import records
+
 
 __all__ = [
     'Media',
@@ -60,6 +63,18 @@ class Media(object):
         """Renvoie un booléen pour savoir si le fichier existe ou pas"""
         return self.filename in os.listdir(CONFIG['APP']['media_folder'])
 
+    def details(self):
+        """Titre et description du film (le synopsis)"""
+        filename = self.filename.replace('.ts', '')
+        with records.Database(MEDIA_SYNOPSIS_DB) as db:
+            sql = (
+                "SELECT name, description "
+                "FROM media WHERE filename=:filename"
+                )
+            rows = db.query(sql, filename=filename)
+            info = rows.first()
+            return info
+
     @property
     def duration(self):
         """Calcul de la durée en secondes"""
