@@ -15,6 +15,7 @@ import collections
 import itertools
 import os
 import shlex
+import string
 import subprocess
 import time
 
@@ -26,6 +27,44 @@ import xmltodict
 __all__ = ['Program']
 
 
+def build_tmira_datetime(dt):
+    """Créer une datetime au format de epg.blueline.mg.
+    Le format d'entrée est %d/%m/%Y %H:%M:%S
+    """
+    date, hour = dt.split()
+    day, month, year = date.split('/')
+    result = '{year}-{month}-{day}T{hour}+03:00'.format(
+        hour=hour, year=year, month=month, day=day)
+    return result
+
+
+def createtitle(name):
+    """Créer un titre avec un nom de fichier media"""
+    name = name
+    if name.endswith('.ts'):
+        name = name[:-3]
+    header = name
+    name = header.replace('_', ' ').title()
+    letters = [
+        i for i in string.letters[26:]
+        if i not in ['A', 'E', 'I', 'O']
+        ]
+    for letter in letters:
+        if ' '+letter+' ' in name:
+            name = name.replace(letter+' ', letter+"'")
+    bar = [i for i in name.split("'")[:-1] if len(i) > 1]
+    for j in bar:
+        name = name.replace(j+"'", j+" ")
+    if name.startswith('Ba '):
+        name = name.replace('Ba ', 'Bande Annonce ')
+    else:
+        name = name.replace(' Ctv4', '')
+        name = name.replace(' Ctv3', '')
+        name = name.replace(' Ctv2', '')
+        name = name.replace(' Ctv', '')
+    return name
+
+
 class Program(object):
     """représente une succession de fichiers media
     à jouer pendant une journée, sur une chaine précise
@@ -87,6 +126,80 @@ class Program(object):
                         }
         return result
 
+    def tmira_xmltv(self):
+        """Créé un fichier XMLTV à charger sur epg.blueline.mg.
+        Les informations sur les synopsis des films sont dans
+        une base de données.
+        """
+        xml = {
+            'BroadcastData': {
+                'ProviderInfo': {
+                    'ProviderId': '',
+                    'ProviderName': '',
+                    },
+                'ScheduleData': {
+                    'ChannelPeriod': {
+                        'ChannelId': self.service_id,
+                        'Event': [],
+                        },
+                    },
+                },
+            }
+        channelperiod = xml['BroadcastData']['ScheduleData']
+        channelperiod = channelperiod['ChannelPeriod']
+        infos = self.infos()
+        timestamps = sorted(infos)
+        for timestamp in timestamps:
+            filename = infos[timestamp]
+            if not filename.startswith('ba_'):
+                # on n'inclue pas les fichiers de bande
+                # annonce dans l'EPG
+                start = datetime.fromtimestamp(
+                    timestamp
+                    ).strftime(
+                        '%d/%m/%Y %H:%M:%S'
+                        )
+                filename = filename.split('/')[-1].split(':')[0]
+                tsfile = media.Media(filename)
+                info = tsfile.details()
+                if not info:
+                    name = filename.replace('.ts', '')
+                    desc = ''
+                else:
+                    name = info.name
+                    desc = info.description
+                if '@beginTime' not in channelperiod:
+                    channelperiod['@beginTime'] = build_tmira_datetime(start)
+                event = {
+                    '@duration': str(tsfile.duration),
+                    '@beginTime': build_tmira_datetime(start),
+                    'EventType': 'S',
+                    'FreeAccess': '1',
+                    'Unscrambled': '1',
+                    'EpgProduction': {
+                        'ParentalRating': {
+                            '@countryCode': "MDG",
+                            '#text': '0',
+                            },
+                        'DvbContent': {
+                            'Content': {
+                                '@nibble2': '0',
+                                '@nibble1': '0',
+                                },
+                            },
+                        'EpgText': {
+                            '@language': 'fre',
+                            'ShortDescription': '',
+                            'Description': desc,
+                            'Name': name,
+                            },
+                        },
+                    }
+                channelperiod['Event'].append(event)
+        else:
+            channelperiod['@endTime'] = build_tmira_datetime(start)
+        return xml
+
     def get_filename_schedule(self, filename):
         """Renvoie le(s) timestamp(s) au(x)quel(s)
         un fichier est censé être diffusé
